@@ -550,7 +550,6 @@ create_treeview (EogCloseConfirmationDialogPrivate *priv)
 	GtkTreeViewColumn *column;
 
 	treeview = gtk_tree_view_new ();
-	gtk_widget_set_size_request (treeview, 260, 120);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview), FALSE);
 
@@ -673,6 +672,7 @@ build_multiple_imgs_dialog (EogCloseConfirmationDialog *dlg)
 
 	treeview = create_treeview (priv);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
+	gtk_widget_set_size_request (scrolledwindow, 260, 120);
 
 	/* Secondary label */
 	secondary_label = gtk_label_new (_("If you don't save, "
